package geniusweb.partiesserver.repository;

import geniusweb.party.Capabilities;
import geniusweb.party.Party;
import tudelft.utilities.repository.RepoElement;

/**
 * An interface to an approved and ready to run party. To make a party
 * available, resources may have to be allocated.
 */
public interface AvailableParty extends RepoElement<String> {

	/**
	 * 
	 * @return the (file) name of the available party
	 */
	String getName();

	/**
	 * 
	 * @return cached copy of what was received from a call to
	 *         {@link Party#getDescription()}.
	 */
	String getDescription();

	/**
	 * 
	 * @return cached copy of what was received from a call to
	 *         {@link AvailableParty#getCapabilities()}
	 */
	Capabilities getCapabilities();

	/**
	 * 
	 * @return a link to a Party. Notice, Party may be a intermediary,
	 *         redirecting data through remote objects
	 * @throws InstantiationFailedException if party can not be instantiated
	 *                                      (this should normally not happen,
	 *                                      since we test thoroughly before a
	 *                                      party is announced Available, but
	 *                                      there might be special cases eg out
	 *                                      of memory)
	 */
	Party getInstance() throws InstantiationFailedException;

	/**
	 * Free resources associated with this . After this call, the AvailableParty
	 * becomes invalid and should be disposed.
	 */
	void free();
}
